==> vtigercrm-5.2.1.tgz: modules/Accounts/language/fr_fr.lang.php <==
<?php
/***********************************************************
*  Module       : Accounts
*  Language     : Francais
*  Version      : 5.1.0 GA*  Created Date : 2009-06-23 21:36:13 
*  Last change  : 2009-07-21 00:49:17
*  Author       : french-vtiger.fr 
*  License      : GPL

***********************************************************/


$mod_strings = array (
		'LBL_MODULE_NAME' => 'Comptes',
		'LBL_MODULE_TITLE' => 'Comptes : accueil',
		'LBL_SEARCH_FORM_TITLE' => 'Rechercher comptes',
		'LBL_LIST_FORM_TITLE' => 'Liste des comptes',
		'LBL_NEW_FORM_TITLE' => 'Nouveau compte',
		'LBL_MEMBER_ORG_FORM_TITLE' => 'Filiale de',
		'LBL_TOP_ACCOUNTS' => 'Top comptes',
		'LBL_TOP_AMOUNT' => 'Montant',
		'LBL_LIST_ACCOUNT_NAME' => 'Nom compte',
		'LBL_LIST_CITY' => 'Ville ',
		'LBL_LIST_WEBSITE' => 'Site Web',
		'LBL_LIST_STATE' => 'Département',
		'LBL_LIST_PHONE' => 'Téléphone',
		'LBL_LIST_EMAIL_ADDRESS' => 'Adresse email',
		'LBL_LIST_CONTACT_NAME' => 'Nom du contact',
		'LBL_LIST_AMOUNT' => 'Total affaires',
		'db_name' => LBL_LIST_ACCOUNT_NAME,
		'db_website' => LBL_LIST_WEBSITE,
		'db_billing_address_city' => LBL_LIST_CITY,
		'LBL_ACCOUNT' => 'Compte :',
		'LBL_ACCOUNT_NAME' => 'Nom compte :',
		'LBL_PHONE' => 'Téléphone :',
		'LBL_WEBSITE' => 'Site Web :',
		'LBL_FAX' => 'Fax :',
		'LBL_TICKER_SYMBOL' => 'Symbole boursier :',
		'LBL_OTHER_PHONE' => 'Téléphone (alt.)',
		'LBL_ANY_PHONE' => 'Téléphone (alt.)',
		'LBL_MEMBER_OF' => 'Filiale de :',
		'LBL_EMAIL' => 'Email :',
		'LBL_EMPLOYEES' => 'Effectif :',
		'LBL_OTHER_EMAIL_ADDRESS' => 'Email (alt.) :',
		'LBL_ANY_EMAIL' => 'Email (alt.) :',
		'LBL_OWNERSHIP' => 'Propriétaire :',
		'LBL_RATING' => 'Notre :',
		'LBL_INDUSTRY' => 'Secteur :',
		'LBL_SIC_CODE' => 'Code APE :',
		'LBL_TYPE' => 'Type :',
		'LBL_ANNUAL_REVENUE' => 'CA :',
		'LBL_ADDRESS_INFORMATION' => 'Détail adresses',
		'LBL_ACCOUNT_INFORMATION' => 'Détail compte',
		'LBL_CUSTOM_INFORMATION' => 'Informations personnalisées',
		'LBL_BILLING_ADDRESS' => 'Adresse (facturation) :',
		'LBL_SHIPPING_ADDRESS' => 'Adresse (livraison) :',
		'LBL_ANY_ADDRESS' => 'Adresse (alt.):',
		'LBL_CITY' => 'Ville :',
		'LBL_STATE' => 'Département :',
		'LBL_POSTAL_CODE' => 'Code postal :',
		'LBL_COUNTRY' => 'Pays :',
		'LBL_DESCRIPTION_INFORMATION' => 'Informations complémentaires',
		'LBL_DESCRIPTION' => 'Description :',
		'NTC_COPY_BILLING_ADDRESS' => 'Utiliser adresse de facturation pour la livraison',
		'NTC_COPY_SHIPPING_ADDRESS' => 'Utiliser adresse de livraison pour la facturation',
		'NTC_REMOVE_MEMBER_ORG_CONFIRMATION' => 'Etes-vous certain de vouloir désolidariser cet enregistrement du groupe ?',
		'LBL_DUPLICATE' => 'Doublon probable',
		'MSG_DUPLICATE' => 'Créer ce compte engeandrera probablement un doublon. Vous pouvez au choix, forcer la création de ce compte ou en sélectionner un dans la liste ci-dessous',
		'LBL_INVITEE' => 'Contacts',
		'ERR_DELETE_RECORD' => 'Un numéro d\'enregistrement doit être spécifié pour supprimer le compte.',
		'LBL_SELECT_ACCOUNT' => 'Sélectionner compte',
		'LBL_GENERAL_INFORMATION' => 'Information',
		'LBL_NEW_POTENTIAL' => 'Nouvelle affaire',
		'LBL_POTENTIAL_TITLE' => 'Affaires',
		'LBL_NEW_TASK' => 'Nouvelle tâche',
		'LBL_TASK_TITLE' => 'Tâches',
		'LBL_NEW_CALL' => 'Nouvel appel',
		'LBL_CALL_TITLE' => 'Appels',
		'LBL_NEW_MEETING' => 'Nouveau rendez-vous',
		'LBL_MEETING_TITLE' => 'Rendez-vous',
		'LBL_NEW_EMAIL' => 'Nouvel email',
		'LBL_EMAIL_TITLE' => 'Emails',
		'LBL_NEW_CONTACT' => 'Nouveau contact',
		'LBL_CONTACT_TITLE' => 'Contacts',
		'LBL_ALL' => 'Tous',
		'LBL_PROSPECT' => 'Prospect',
		'LBL_INVESTOR' => 'Investisseur',
		'LBL_RESELLER' => 'Revendeur',
		'LBL_PARTNER' => 'Partenaire',
		'LBL_TOOL_FORM_TITLE' => 'Outils',
		'Account Name' => 'Nom compte',
		'Phone' => 'Téléphone',
		'Website' => 'Site Web',
		'Fax' => 'Fax',
		'Ticker Symbol' => 'Symbole boursier',
		'Other Phone' => 'Téléphone (alt.)',
		'Member Of' => 'Filiale de',
		'Email' => 'Email',
		'Employees' => 'Effectif',
		'Other Email' => 'Autre email',
		'Ownership' => 'Propriétaire',
		'Rating' => 'Etat',
		'industry' => 'Secteur',
		'SIC Code' => 'Code APE',
		'Type' => 'Type',
		'Annual Revenue' => 'C.A. annuel',
		'Assigned To' => 'Assigné à',
		'Billing Address' => 'Adresse (facturation)',
		'Shipping Address' => 'Adresse (livraison)',
		'Billing City' => 'Ville (facturation)',
		'Shipping City' => 'Ville (livraison)',
		'Billing State' => 'Département (facturation)',
		'Shipping State' => 'Département (livraison)',
		'Billing Code' => 'Code postal (facturation)',
		'Shipping Code' => 'Code postal (livraison)',
		'Billing Country' => 'Pays(facturation)',
		'Shipping Country' => 'Pays (livraison)',
		'Created Time' => 'Créé le',
		'Modified Time' => 'Modifié le',
		'Description' => 'Description',
		'Shipping Po Box' => 'Boite postale (livraison)',
		'Billing Po Box' => 'Boite postale (facturation)',
		'Email Opt Out' => 'Ne pas contacter par email',
		'LBL_EMAIL_OPT_OUT' => 'Ne pas contacter par email :',
		'Notify Owner' => 'Notifier le collaborateur assigné',
		'--None--' => '--Aucun--',
		'Acquired' => 'Acquis',
		'Active' => 'Actif',
		'Market Failed' => 'Perdu',
		'Project Cancelled' => 'Projet abandonné',
		'Shutdown' => 'Eteint',
		'Apparel' => 'Habillement',
		'Banking' => 'Banque',
		'Biotechnology' => 'Biotechnologie',
		'Chemicals' => 'Chimie',
		'Communications' => 'Communications',
		'Construction' => 'BTP',
		'Consulting' => 'Consulting',
		'Education' => 'Education',
		'Electronics' => 'Electronique',
		'Energy' => 'Energie',
		'Engineering' => 'Ingénierie',
		'Entertainment' => 'Divertissement',
		'Environmental' => 'Environnement',
		'Finance' => 'Finance',
		'Food & Beverage' => 'Agro-alimentaire',
		'Government' => 'Secteur public',
		'Healthcare' => 'Santé',
		'Hospitality' => 'Hôpitaux',
		'Insurance' => 'Assurances',
		'Machinery' => 'Construction mécanique',
		'Manufacturing' => 'Fabrication',
		'Media' => 'Médias',
		'Not For Profit' => 'Associatif',
		'Recreation' => 'Récréatif',
		'Retail' => 'Détaillant',
		'Shipping' => 'Livreur',
		'Technology' => 'Technologie',
		'Telecommunications' => 'Télécommunications',
		'Transportation' => 'Transport',
		'Utilities' => 'Utilitaire',
		'Other' => 'Autre',
		'Analyst' => 'Analyste',
		'Competitor' => 'Concurrent',
		'Customer' => 'Client',
		'Integrator' => 'Intégrateur',
		'Investor' => 'Investisseur',
		'Partner' => 'Partenaire',
		'Press' => 'Presse',
		'Prospect' => 'Prospect',
		'Reseller' => 'Revendeur',
		'LBL_START_DATE' => 'Date de début',
		'LBL_END_DATE' => 'Date de fin',
		'LBL_ACCOUNT_EXIST' => 'Ce nom de compte est déjà utilisé',
		'LBL_MAILER_EXPORT' => 'Mailer Export',
		'LBL_MAILER_EXPORT_CONTACTS_TYPE' => 'Selectionner le contact :',
		'LBL_MAILER_EXPORT_CONTACTS_DESCR' => 'Les contacts peuvent également être sélectionnés via \"Champs personnalisés\" et d\'autres champs standards.',
		'LBL_MAILER_EXPORT_RESULTS_TYPE' => 'Sélectionnez un type d\'export',
		'LBL_MAILER_EXPORT_RESULTS_DESCR' => 'Les données seront prises des comptes et leurs contacts qui ont été sélectionnés de la recherche précédente.',
		'LBL_EXPORT_RESULTS_EMAIL' => 'Données d\'export par email',
		'LBL_EXPORT_RESULTS_EMAIL_CORP' => 'Pendant l\'export des données mails, utiliser l\'email de l\'entreprise du compte si le champ Email du contact est vide',
		'LBL_EXPORT_RESULTS_FULL' => 'Exporter les données avec les contacts, emails, noms de compte, adresses, téléphones, etc.',
		'LBL_EXPORT_RESULTS_GO' => 'Exporter',
		'LBL_MAILER_EXPORT_IGNORE' => '--ignorer--',
		'LBL_MAILER_EXPORT_CHECKED' => 'Sélectionné',
		'LBL_MAILER_EXPORT_NOTCHECKED' => 'Non sélectionné',
		//Module Sequence Numbering
		'Account No'=>'Compte N°',
		// END

		// Account Hierarchy
		'LBL_SHOW_ACCOUNT_HIERARCHY' => 'Afficher la hiérarchie des comptes', 
);
$mod_list_strings = array (
);
?>

==> vtigercrm-5.4.0.tgz: modules/Accounts/language/fr_fr.lang.php <==
<?php
/***********************************************************
*  Module       : Accounts
*  Language     : French
*  Version      : 5.4.0 
*  License      : GPL
*  Author       : ABOnline solutions http://www.vtiger-crm.fr
***********************************************************/

$mod_strings = array (
		'LBL_MODULE_NAME' => 'Comptes',
		'LBL_MODULE_TITLE' => 'Comptes : accueil',
		'LBL_SEARCH_FORM_TITLE' => 'Rechercher comptes',
		'LBL_LIST_FORM_TITLE' => 'Liste des comptes',
		'LBL_NEW_FORM_TITLE' => 'Nouveau compte',
		'LBL_MEMBER_ORG_FORM_TITLE' => 'Filiale de',
		'LBL_TOP_ACCOUNTS' => 'Top comptes',
		'LBL_TOP_AMOUNT' => 'Montant',
		'LBL_LIST_ACCOUNT_NAME' => 'Nom compte',
		'LBL_LIST_CITY' => 'Ville ',
		'LBL_LIST_WEBSITE' => 'Site Web',
		'LBL_LIST_STATE' => 'Département',
		'LBL_LIST_PHONE' => 'Téléphone',
		'LBL_LIST_EMAIL_ADDRESS' => 'Adresse email',
		'LBL_LIST_CONTACT_NAME' => 'Nom du contact',
		'LBL_LIST_AMOUNT' => 'Total affaires',
		'db_name' => LBL_LIST_ACCOUNT_NAME,
		'db_website' => LBL_LIST_WEBSITE,
		'db_billing_address_city' => LBL_LIST_CITY,
		'LBL_ACCOUNT' => 'Compte :',
		'LBL_ACCOUNT_NAME' => 'Nom compte :',
		'LBL_PHONE' => 'Téléphone :',
		'LBL_WEBSITE' => 'Site Web :',
		'LBL_FAX' => 'Fax :',
		'LBL_TICKER_SYMBOL' => 'Symbole boursier :',
		'LBL_OTHER_PHONE' => 'Téléphone (alt.)',
		'LBL_ANY_PHONE' => 'Téléphone (alt.)',
		'LBL_MEMBER_OF' => 'Filiale de :',
		'LBL_EMAIL' => 'Email :',
		'LBL_EMPLOYEES' => 'Effectif :',
		'LBL_OTHER_EMAIL_ADDRESS' => 'Email (alt.) :',
		'LBL_ANY_EMAIL' => 'Email (alt.) :',
		'LBL_OWNERSHIP' => 'Propriétaire :',
		'LBL_RATING' => 'Notre :',
		'LBL_INDUSTRY' => 'Secteur :',
		'LBL_SIC_CODE' => 'Code APE :',
		'LBL_TYPE' => 'Type :',
		'LBL_ANNUAL_REVENUE' => 'CA :',
		'LBL_ADDRESS_INFORMATION' => 'Détail adresses',
		'LBL_ACCOUNT_INFORMATION' => 'Détail compte',
		'LBL_CUSTOM_INFORMATION' => 'Informations personnalisées',
		'LBL_BILLING_ADDRESS' => 'Adresse (facturation) :',
		'LBL_SHIPPING_ADDRESS' => 'Adresse (livraison) :',
		'LBL_ANY_ADDRESS' => 'Adresse (alt.):',
		'LBL_CITY' => 'Ville :',
		'LBL_STATE' => 'Département :',
		'LBL_POSTAL_CODE' => 'Code postal :',
		'LBL_COUNTRY' => 'Pays :',
		'LBL_DESCRIPTION_INFORMATION' => 'Informations complémentaires',
		'LBL_DESCRIPTION' => 'Description :',
		'NTC_COPY_BILLING_ADDRESS' => 'Utiliser adresse de facturation pour la livraison',
		'NTC_COPY_SHIPPING_ADDRESS' => 'Utiliser adresse de livraison pour la facturation',
		'NTC_REMOVE_MEMBER_ORG_CONFIRMATION' => 'Etes-vous certain de vouloir désolidariser cet enregistrement du groupe ?',
		'LBL_DUPLICATE' => 'Doublon probable',
		'MSG_DUPLICATE' => 'Créer ce compte engeandrera probablement un doublon. Vous pouvez au choix, forcer la création de ce compte ou en sélectionner un dans la liste ci-dessous',
		'LBL_INVITEE' => 'Contacts',
		'ERR_DELETE_RECORD' => 'Un numéro d\'enregistrement doit être spécifié pour supprimer le compte.',
		'LBL_SELECT_ACCOUNT' => 'Sélectionner compte',
		'LBL_GENERAL_INFORMATION' => 'Information',
		'LBL_NEW_POTENTIAL' => 'Nouvelle affaire',
		'LBL_POTENTIAL_TITLE' => 'Affaires',
		'LBL_NEW_TASK' => 'Nouvelle tâche',
		'LBL_TASK_TITLE' => 'Tâches',
		'LBL_NEW_CALL' => 'Nouvel appel',
		'LBL_CALL_TITLE' => 'Appels',
		'LBL_NEW_MEETING' => 'Nouveau rendez-vous',
		'LBL_MEETING_TITLE' => 'Rendez-vous',
		'LBL_NEW_EMAIL' => 'Nouvel email',
		'LBL_EMAIL_TITLE' => 'Emails',
		'LBL_NEW_CONTACT' => 'Nouveau contact',
		'LBL_CONTACT_TITLE' => 'Contacts',
		'LBL_ALL' => 'Tous',
		'LBL_PROSPECT' => 'Prospect',
		'LBL_INVESTOR' => 'Investisseur',
		'LBL_RESELLER' => 'Revendeur',
		'LBL_PARTNER' => 'Partenaire',
		'LBL_TOOL_FORM_TITLE' => 'Outils',
		'Account Name' => 'Nom compte',
		'Phone' => 'Téléphone',
		'Website' => 'Site Web',
		'Fax' => 'Fax',
		'Ticker Symbol' => 'Symbole boursier',
		'Other Phone' => 'Téléphone (alt.)',
		'Member Of' => 'Filiale de',
		'Email' => 'Email',
		'Employees' => 'Effectif',
		'Other Email' => 'Autre email',
		'Ownership' => 'Propriétaire',
		'Rating' => 'Etat',
		'industry' => 'Secteur',
		'SIC Code' => 'Code APE',
		'Type' => 'Type',
		'Annual Revenue' => 'C.A. annuel',
		'Assigned To' => 'Assigné à',
		'Billing Address' => 'Adresse (facturation)',
		'Shipping Address' => 'Adresse (livraison)',
		'Billing City' => 'Ville (facturation)',
		'Shipping City' => 'Ville (livraison)',
		'Billing State' => 'Département (facturation)',
		'Shipping State' => 'Département (livraison)',
		'Billing Code' => 'Code postal (facturation)',
		'Shipping Code' => 'Code postal (livraison)',
		'Billing Country' => 'Pays (facturation)',
		'Shipping Country' => 'Pays (livraison)',
		'Created Time' => 'Créé le',
		'Modified Time' => 'Modifié le',
		'Description' => 'Description',
		'Shipping Po Box' => 'Boite postale (livraison)',
		'Billing Po Box' => 'Boite postale (facturation)',
		'Email Opt Out' => 'Ne pas contacter par email',
		'LBL_EMAIL_OPT_OUT' => 'Ne pas contacter par email :',
		'Notify Owner' => 'Notifier le collaborateur assigné',
		'--None--' => '--Aucun--',
		'Acquired' => 'Acquis',
		'Active' => 'Actif',
		'Market Failed' => 'Perdu',
		'Project Cancelled' => 'Projet abandonné',
		'Shutdown' => 'Eteint',
		'Apparel' => 'Habillement',
		'Banking' => 'Banque',
		'Biotechnology' => 'Biotechnologie',
		'Chemicals' => 'Chimie',
		'Communications' => 'Communications',
		'Construction' => 'BTP',
		'Consulting' => 'Consulting',
		'Education' => 'Education',
		'Electronics' => 'Electronique',
		'Energy' => 'Energie',
		'Engineering' => 'Ingénierie',
		'Entertainment' => 'Divertissement',
		'Environmental' => 'Environnement',
		'Finance' => 'Finance',
		'Food & Beverage' => 'Agro-alimentaire',
		'Government' => 'Secteur public',
		'Healthcare' => 'Santé',
		'Hospitality' => 'Hôpitaux',
		'Insurance' => 'Assurances',
		'Machinery' => 'Construction mécanique',
		'Manufacturing' => 'Fabrication',
		'Media' => 'Médias',
		'Not For Profit' => 'Associatif',
		'Recreation' => 'Récréatif',
		'Retail' => 'Détaillant',
		'Shipping' => 'Livreur',
		'Technology' => 'Technologie',
		'Telecommunications' => 'Télécommunications',
		'Transportation' => 'Transport',
		'Utilities' => 'Utilitaire',
		'Other' => 'Autre',
		'Analyst' => 'Analyste',
		'Competitor' => 'Concurrent',
		'Customer' => 'Client',
		'Integrator' => 'Intégrateur',
		'Investor' => 'Investisseur',
		'Partner' => 'Partenaire',
		'Press' => 'Presse',
		'Prospect' => 'Prospect',
		'Reseller' => 'Revendeur',
		'LBL_START_DATE' => 'Date de début',
		'LBL_END_DATE' => 'Date de fin',
		'LBL_ACCOUNT_EXIST' => 'Ce nom de compte est déjà utilisé',
		'LBL_MAILER_EXPORT' => 'Mailer Export',
		'LBL_MAILER_EXPORT_CONTACTS_TYPE' => 'Selectionner le contact :',
		'LBL_MAILER_EXPORT_CONTACTS_DESCR' => 'Les contacts peuvent également être sélectionnés via "Champs personnalisés" et d\'autres champs standards.',
		'LBL_MAILER_EXPORT_RESULTS_TYPE' => 'Sélectionnez un type d\'export',
		'LBL_MAILER_EXPORT_RESULTS_DESCR' => 'Les données seront prises des comptes et leurs contacts qui ont été sélectionnés de la recherche précédente.',
		'LBL_EXPORT_RESULTS_EMAIL' => 'Données d\'export par email',
		'LBL_EXPORT_RESULTS_EMAIL_CORP' => 'Pendant l\'export des données mails, utiliser l\'email de l\'entreprise du compte si le champ Email du contact est vide',
		'LBL_EXPORT_RESULTS_FULL' => 'Exporter les données avec les contacts, emails, noms de compte, adresses, téléphones, etc.',
		'LBL_EXPORT_RESULTS_GO' => 'Exporter',
		'LBL_MAILER_EXPORT_IGNORE' => '--ignorer--',
		'LBL_MAILER_EXPORT_CHECKED' => 'Sélectionné',
		'LBL_MAILER_EXPORT_NOTCHECKED' => 'Non sélectionné',
		//Module Sequence Numbering
		'Account No'=>'Compte N°',
		// END

		// Account Hierarchy
		'LBL_SHOW_ACCOUNT_HIERARCHY' => 'Afficher la hiérarchie des comptes', 
		'Accounts ID' => 'Compte ID',
);
$mod_list_strings = array (
);
?>
